@@ -115,9 +115,16 @@ def parse_google_drive_file(folder, content, use_cookies=True):
 
     folder_contents = [] if folder_arr[0] is None else folder_arr[0]
 
+    seps = [" - ", " – "]  # unicode dash and endash
+    for sep in seps:
+        splitted = folder_soup.title.contents[0].split(sep)
+        if len(splitted) >= 2:
+            name = sep.join(splitted[:-1])
+            break
+
     gdrive_file = GoogleDriveFile(
         id=folder.split("/")[-1],
-        name=" - ".join(folder_soup.title.contents[0].split(" - ")[:-1]),
+        name=name,
         type=folder_type,
     )
 
@@ -200,6 +207,7 @@ def download_and_parse_google_drive_link(
             folders_url + child_id,
             use_cookies=use_cookies,
             quiet=quiet,
+            remaining_ok=remaining_ok,
         )
         if not return_code:
             return return_code, None
@@ -236,6 +244,7 @@ def get_directory_structure(gdrive_file, previous_path):
     """
     directory_structure = []
     for file in gdrive_file.children:
+        file.name = file.name.replace(osp.sep, "_")
         if file.is_folder():
             directory_structure.append(
                 (None, osp.join(previous_path, file.name))
